# swagger_client

SwaggerClient - the Ruby gem for the Figshare API

Figshare apiv2. Using Swagger 2.0

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build swagger_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./swagger_client-1.0.0.gem
```
(for development, run `gem install --dev ./swagger_client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'swagger_client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'swagger_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'swagger_client'

# Setup authorization
SwaggerClient.configure do |config|
  # Configure OAuth2 access token for authorization: OAuth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = SwaggerClient::ArticlesApi.new

opts = { 
  group_id: 789 # Integer | A group ID to filter by
}

begin
  #Account Article Report
  result = api_instance.account_article_report(opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling ArticlesApi->account_article_report: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.figshare.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*SwaggerClient::ArticlesApi* | [**account_article_report**](docs/ArticlesApi.md#account_article_report) | **GET** /account/articles/export | Account Article Report
*SwaggerClient::ArticlesApi* | [**account_article_report_generate**](docs/ArticlesApi.md#account_article_report_generate) | **POST** /account/articles/export | Initiate a new Report
*SwaggerClient::ArticlesApi* | [**article_details**](docs/ArticlesApi.md#article_details) | **GET** /articles/{article_id} | View article details
*SwaggerClient::ArticlesApi* | [**article_file_details**](docs/ArticlesApi.md#article_file_details) | **GET** /articles/{article_id}/files/{file_id} | Article file details
*SwaggerClient::ArticlesApi* | [**article_files**](docs/ArticlesApi.md#article_files) | **GET** /articles/{article_id}/files | List article files
*SwaggerClient::ArticlesApi* | [**article_version_confidentiality**](docs/ArticlesApi.md#article_version_confidentiality) | **GET** /articles/{article_id}/versions/{v_number}/confidentiality | Public Article Confidentiality for article version
*SwaggerClient::ArticlesApi* | [**article_version_details**](docs/ArticlesApi.md#article_version_details) | **GET** /articles/{article_id}/versions/{v_number} | Article details for version
*SwaggerClient::ArticlesApi* | [**article_version_embargo**](docs/ArticlesApi.md#article_version_embargo) | **GET** /articles/{article_id}/versions/{v_number}/embargo | Public Article Embargo for article version
*SwaggerClient::ArticlesApi* | [**article_version_update**](docs/ArticlesApi.md#article_version_update) | **PUT** /account/articles/{article_id}/versions/{version_id}/ | Update article version
*SwaggerClient::ArticlesApi* | [**article_version_update_thumb**](docs/ArticlesApi.md#article_version_update_thumb) | **PUT** /account/articles/{article_id}/versions/{version_id}/update_thumb | Update article version thumbnail
*SwaggerClient::ArticlesApi* | [**article_versions**](docs/ArticlesApi.md#article_versions) | **GET** /articles/{article_id}/versions | List article versions
*SwaggerClient::ArticlesApi* | [**articles_list**](docs/ArticlesApi.md#articles_list) | **GET** /articles | Public Articles
*SwaggerClient::ArticlesApi* | [**articles_search**](docs/ArticlesApi.md#articles_search) | **POST** /articles/search | Public Articles Search
*SwaggerClient::ArticlesApi* | [**private_article_author_delete**](docs/ArticlesApi.md#private_article_author_delete) | **DELETE** /account/articles/{article_id}/authors/{author_id} | Delete article author
*SwaggerClient::ArticlesApi* | [**private_article_authors_add**](docs/ArticlesApi.md#private_article_authors_add) | **POST** /account/articles/{article_id}/authors | Add article authors
*SwaggerClient::ArticlesApi* | [**private_article_authors_list**](docs/ArticlesApi.md#private_article_authors_list) | **GET** /account/articles/{article_id}/authors | List article authors
*SwaggerClient::ArticlesApi* | [**private_article_authors_replace**](docs/ArticlesApi.md#private_article_authors_replace) | **PUT** /account/articles/{article_id}/authors | Replace article authors
*SwaggerClient::ArticlesApi* | [**private_article_categories_add**](docs/ArticlesApi.md#private_article_categories_add) | **POST** /account/articles/{article_id}/categories | Add article categories
*SwaggerClient::ArticlesApi* | [**private_article_categories_list**](docs/ArticlesApi.md#private_article_categories_list) | **GET** /account/articles/{article_id}/categories | List article categories
*SwaggerClient::ArticlesApi* | [**private_article_categories_replace**](docs/ArticlesApi.md#private_article_categories_replace) | **PUT** /account/articles/{article_id}/categories | Replace article categories
*SwaggerClient::ArticlesApi* | [**private_article_category_delete**](docs/ArticlesApi.md#private_article_category_delete) | **DELETE** /account/articles/{article_id}/categories/{category_id} | Delete article category
*SwaggerClient::ArticlesApi* | [**private_article_confidentiality_delete**](docs/ArticlesApi.md#private_article_confidentiality_delete) | **DELETE** /account/articles/{article_id}/confidentiality | Delete article confidentiality
*SwaggerClient::ArticlesApi* | [**private_article_confidentiality_details**](docs/ArticlesApi.md#private_article_confidentiality_details) | **GET** /account/articles/{article_id}/confidentiality | Article confidentiality details
*SwaggerClient::ArticlesApi* | [**private_article_confidentiality_update**](docs/ArticlesApi.md#private_article_confidentiality_update) | **PUT** /account/articles/{article_id}/confidentiality | Update article confidentiality
*SwaggerClient::ArticlesApi* | [**private_article_create**](docs/ArticlesApi.md#private_article_create) | **POST** /account/articles | Create new Article
*SwaggerClient::ArticlesApi* | [**private_article_delete**](docs/ArticlesApi.md#private_article_delete) | **DELETE** /account/articles/{article_id} | Delete article
*SwaggerClient::ArticlesApi* | [**private_article_details**](docs/ArticlesApi.md#private_article_details) | **GET** /account/articles/{article_id} | Article details
*SwaggerClient::ArticlesApi* | [**private_article_embargo_delete**](docs/ArticlesApi.md#private_article_embargo_delete) | **DELETE** /account/articles/{article_id}/embargo | Delete Article Embargo
*SwaggerClient::ArticlesApi* | [**private_article_embargo_details**](docs/ArticlesApi.md#private_article_embargo_details) | **GET** /account/articles/{article_id}/embargo | Article Embargo Details
*SwaggerClient::ArticlesApi* | [**private_article_embargo_update**](docs/ArticlesApi.md#private_article_embargo_update) | **PUT** /account/articles/{article_id}/embargo | Update Article Embargo
*SwaggerClient::ArticlesApi* | [**private_article_file**](docs/ArticlesApi.md#private_article_file) | **GET** /account/articles/{article_id}/files/{file_id} | Single File
*SwaggerClient::ArticlesApi* | [**private_article_file_delete**](docs/ArticlesApi.md#private_article_file_delete) | **DELETE** /account/articles/{article_id}/files/{file_id} | File Delete
*SwaggerClient::ArticlesApi* | [**private_article_files_list**](docs/ArticlesApi.md#private_article_files_list) | **GET** /account/articles/{article_id}/files | List article files
*SwaggerClient::ArticlesApi* | [**private_article_private_link**](docs/ArticlesApi.md#private_article_private_link) | **GET** /account/articles/{article_id}/private_links | List private links
*SwaggerClient::ArticlesApi* | [**private_article_private_link_create**](docs/ArticlesApi.md#private_article_private_link_create) | **POST** /account/articles/{article_id}/private_links | Create private link
*SwaggerClient::ArticlesApi* | [**private_article_private_link_delete**](docs/ArticlesApi.md#private_article_private_link_delete) | **DELETE** /account/articles/{article_id}/private_links/{link_id} | Disable private link
*SwaggerClient::ArticlesApi* | [**private_article_private_link_update**](docs/ArticlesApi.md#private_article_private_link_update) | **PUT** /account/articles/{article_id}/private_links/{link_id} | Update private link
*SwaggerClient::ArticlesApi* | [**private_article_publish**](docs/ArticlesApi.md#private_article_publish) | **POST** /account/articles/{article_id}/publish | Private Article Publish
*SwaggerClient::ArticlesApi* | [**private_article_reserve_doi**](docs/ArticlesApi.md#private_article_reserve_doi) | **POST** /account/articles/{article_id}/reserve_doi | Private Article Reserve DOI
*SwaggerClient::ArticlesApi* | [**private_article_reserve_handle**](docs/ArticlesApi.md#private_article_reserve_handle) | **POST** /account/articles/{article_id}/reserve_handle | Private Article Reserve Handle
*SwaggerClient::ArticlesApi* | [**private_article_resource**](docs/ArticlesApi.md#private_article_resource) | **POST** /account/articles/{article_id}/resource | Private Article Resource
*SwaggerClient::ArticlesApi* | [**private_article_update**](docs/ArticlesApi.md#private_article_update) | **PUT** /account/articles/{article_id} | Update article
*SwaggerClient::ArticlesApi* | [**private_article_upload_complete**](docs/ArticlesApi.md#private_article_upload_complete) | **POST** /account/articles/{article_id}/files/{file_id} | Complete Upload
*SwaggerClient::ArticlesApi* | [**private_article_upload_initiate**](docs/ArticlesApi.md#private_article_upload_initiate) | **POST** /account/articles/{article_id}/files | Initiate Upload
*SwaggerClient::ArticlesApi* | [**private_articles_list**](docs/ArticlesApi.md#private_articles_list) | **GET** /account/articles | Private Articles
*SwaggerClient::ArticlesApi* | [**private_articles_search**](docs/ArticlesApi.md#private_articles_search) | **POST** /account/articles/search | Private Articles search
*SwaggerClient::AuthorsApi* | [**private_author_details**](docs/AuthorsApi.md#private_author_details) | **GET** /account/authors/{author_id} | Author details
*SwaggerClient::AuthorsApi* | [**private_authors_search**](docs/AuthorsApi.md#private_authors_search) | **POST** /account/authors/search | Search Authors
*SwaggerClient::CollectionsApi* | [**collection_articles**](docs/CollectionsApi.md#collection_articles) | **GET** /collections/{collection_id}/articles | Public Collection Articles
*SwaggerClient::CollectionsApi* | [**collection_details**](docs/CollectionsApi.md#collection_details) | **GET** /collections/{collection_id} | Collection details
*SwaggerClient::CollectionsApi* | [**collection_version_details**](docs/CollectionsApi.md#collection_version_details) | **GET** /collections/{collection_id}/versions/{version_id} | Collection Version details
*SwaggerClient::CollectionsApi* | [**collection_versions**](docs/CollectionsApi.md#collection_versions) | **GET** /collections/{collection_id}/versions | Collection Versions list
*SwaggerClient::CollectionsApi* | [**collections_list**](docs/CollectionsApi.md#collections_list) | **GET** /collections | Public Collections
*SwaggerClient::CollectionsApi* | [**collections_search**](docs/CollectionsApi.md#collections_search) | **POST** /collections/search | Public Collections Search
*SwaggerClient::CollectionsApi* | [**private_collection_article_delete**](docs/CollectionsApi.md#private_collection_article_delete) | **DELETE** /account/collections/{collection_id}/articles/{article_id} | Delete collection article
*SwaggerClient::CollectionsApi* | [**private_collection_articles_add**](docs/CollectionsApi.md#private_collection_articles_add) | **POST** /account/collections/{collection_id}/articles | Add collection articles
*SwaggerClient::CollectionsApi* | [**private_collection_articles_list**](docs/CollectionsApi.md#private_collection_articles_list) | **GET** /account/collections/{collection_id}/articles | List collection articles
*SwaggerClient::CollectionsApi* | [**private_collection_articles_replace**](docs/CollectionsApi.md#private_collection_articles_replace) | **PUT** /account/collections/{collection_id}/articles | Replace collection articles
*SwaggerClient::CollectionsApi* | [**private_collection_author_delete**](docs/CollectionsApi.md#private_collection_author_delete) | **DELETE** /account/collections/{collection_id}/authors/{author_id} | Delete collection author
*SwaggerClient::CollectionsApi* | [**private_collection_authors_add**](docs/CollectionsApi.md#private_collection_authors_add) | **POST** /account/collections/{collection_id}/authors | Add collection authors
*SwaggerClient::CollectionsApi* | [**private_collection_authors_list**](docs/CollectionsApi.md#private_collection_authors_list) | **GET** /account/collections/{collection_id}/authors | List collection authors
*SwaggerClient::CollectionsApi* | [**private_collection_authors_replace**](docs/CollectionsApi.md#private_collection_authors_replace) | **PUT** /account/collections/{collection_id}/authors | Replace collection authors
*SwaggerClient::CollectionsApi* | [**private_collection_categories_add**](docs/CollectionsApi.md#private_collection_categories_add) | **POST** /account/collections/{collection_id}/categories | Add collection categories
*SwaggerClient::CollectionsApi* | [**private_collection_categories_list**](docs/CollectionsApi.md#private_collection_categories_list) | **GET** /account/collections/{collection_id}/categories | List collection categories
*SwaggerClient::CollectionsApi* | [**private_collection_categories_replace**](docs/CollectionsApi.md#private_collection_categories_replace) | **PUT** /account/collections/{collection_id}/categories | Replace collection categories
*SwaggerClient::CollectionsApi* | [**private_collection_category_delete**](docs/CollectionsApi.md#private_collection_category_delete) | **DELETE** /account/collections/{collection_id}/categories/{category_id} | Delete collection category
*SwaggerClient::CollectionsApi* | [**private_collection_create**](docs/CollectionsApi.md#private_collection_create) | **POST** /account/collections | Create collection
*SwaggerClient::CollectionsApi* | [**private_collection_delete**](docs/CollectionsApi.md#private_collection_delete) | **DELETE** /account/collections/{collection_id} | Delete collection
*SwaggerClient::CollectionsApi* | [**private_collection_details**](docs/CollectionsApi.md#private_collection_details) | **GET** /account/collections/{collection_id} | Collection details
*SwaggerClient::CollectionsApi* | [**private_collection_private_link_create**](docs/CollectionsApi.md#private_collection_private_link_create) | **POST** /account/collections/{collection_id}/private_links | Create collection private link
*SwaggerClient::CollectionsApi* | [**private_collection_private_link_delete**](docs/CollectionsApi.md#private_collection_private_link_delete) | **DELETE** /account/collections/{collection_id}/private_links/{link_id} | Disable private link
*SwaggerClient::CollectionsApi* | [**private_collection_private_link_update**](docs/CollectionsApi.md#private_collection_private_link_update) | **PUT** /account/collections/{collection_id}/private_links/{link_id} | Update collection private link
*SwaggerClient::CollectionsApi* | [**private_collection_private_links_list**](docs/CollectionsApi.md#private_collection_private_links_list) | **GET** /account/collections/{collection_id}/private_links | List collection private links
*SwaggerClient::CollectionsApi* | [**private_collection_publish**](docs/CollectionsApi.md#private_collection_publish) | **POST** /account/collections/{collection_id}/publish | Private Collection Publish
*SwaggerClient::CollectionsApi* | [**private_collection_reserve_doi**](docs/CollectionsApi.md#private_collection_reserve_doi) | **POST** /account/collections/{collection_id}/reserve_doi | Private Collection Reserve DOI
*SwaggerClient::CollectionsApi* | [**private_collection_reserve_handle**](docs/CollectionsApi.md#private_collection_reserve_handle) | **POST** /account/collections/{collection_id}/reserve_handle | Private Collection Reserve Handle
*SwaggerClient::CollectionsApi* | [**private_collection_resource**](docs/CollectionsApi.md#private_collection_resource) | **POST** /account/collections/{collection_id}/resource | Private Collection Resource
*SwaggerClient::CollectionsApi* | [**private_collection_update**](docs/CollectionsApi.md#private_collection_update) | **PUT** /account/collections/{collection_id} | Update collection
*SwaggerClient::CollectionsApi* | [**private_collections_list**](docs/CollectionsApi.md#private_collections_list) | **GET** /account/collections | Private Collections List
*SwaggerClient::CollectionsApi* | [**private_collections_search**](docs/CollectionsApi.md#private_collections_search) | **POST** /account/collections/search | Private Collections Search
*SwaggerClient::InstitutionsApi* | [**account_institution_curation**](docs/InstitutionsApi.md#account_institution_curation) | **GET** /account/institution/review/{curation_id} | Institution Curation Review
*SwaggerClient::InstitutionsApi* | [**account_institution_curation_comments**](docs/InstitutionsApi.md#account_institution_curation_comments) | **GET** /account/institution/review/{curation_id}/comments | Institution Curation Review Comments
*SwaggerClient::InstitutionsApi* | [**account_institution_curation_comments_0**](docs/InstitutionsApi.md#account_institution_curation_comments_0) | **POST** /account/institution/review/{curation_id}/comments | POST Institution Curation Review Comment
*SwaggerClient::InstitutionsApi* | [**account_institution_curations**](docs/InstitutionsApi.md#account_institution_curations) | **GET** /account/institution/reviews | Institution Curation Reviews
*SwaggerClient::InstitutionsApi* | [**custom_fields_list**](docs/InstitutionsApi.md#custom_fields_list) | **GET** /account/institution/custom_fields | Private account institution group custom fields
*SwaggerClient::InstitutionsApi* | [**custom_fields_upload**](docs/InstitutionsApi.md#custom_fields_upload) | **POST** /account/institution/custom_fields/{custom_field_id}/items/upload | Custom fields values files upload
*SwaggerClient::InstitutionsApi* | [**institution_articles**](docs/InstitutionsApi.md#institution_articles) | **GET** /institutions/{institution_string_id}/articles/filter-by | Public Institution Articles
*SwaggerClient::InstitutionsApi* | [**institution_hrfeed_upload**](docs/InstitutionsApi.md#institution_hrfeed_upload) | **POST** /institution/hrfeed/upload | Private Institution HRfeed Upload
*SwaggerClient::InstitutionsApi* | [**private_account_institution_user**](docs/InstitutionsApi.md#private_account_institution_user) | **GET** /account/institution/users/{account_id} | Private Account Institution User
*SwaggerClient::InstitutionsApi* | [**private_categories_list**](docs/InstitutionsApi.md#private_categories_list) | **GET** /account/categories | Private Account Categories
*SwaggerClient::InstitutionsApi* | [**private_group_embargo_options_details**](docs/InstitutionsApi.md#private_group_embargo_options_details) | **GET** /account/institution/groups/{group_id}/embargo_options | Private Account Institution Group Embargo Options
*SwaggerClient::InstitutionsApi* | [**private_institution_account_group_role_delete**](docs/InstitutionsApi.md#private_institution_account_group_role_delete) | **DELETE** /account/institution/roles/{account_id}/{group_id}/{role_id} | Delete Institution Account Group Role
*SwaggerClient::InstitutionsApi* | [**private_institution_account_group_roles**](docs/InstitutionsApi.md#private_institution_account_group_roles) | **GET** /account/institution/roles/{account_id} | List Institution Account Group Roles
*SwaggerClient::InstitutionsApi* | [**private_institution_account_group_roles_create**](docs/InstitutionsApi.md#private_institution_account_group_roles_create) | **POST** /account/institution/roles/{account_id} | Add Institution Account Group Roles
*SwaggerClient::InstitutionsApi* | [**private_institution_accounts_create**](docs/InstitutionsApi.md#private_institution_accounts_create) | **POST** /account/institution/accounts | Create new Institution Account
*SwaggerClient::InstitutionsApi* | [**private_institution_accounts_list**](docs/InstitutionsApi.md#private_institution_accounts_list) | **GET** /account/institution/accounts | Private Account Institution Accounts
*SwaggerClient::InstitutionsApi* | [**private_institution_accounts_search**](docs/InstitutionsApi.md#private_institution_accounts_search) | **POST** /account/institution/accounts/search | Private Account Institution Accounts Search
*SwaggerClient::InstitutionsApi* | [**private_institution_accounts_update**](docs/InstitutionsApi.md#private_institution_accounts_update) | **PUT** /account/institution/accounts/{account_id} | Update Institution Account
*SwaggerClient::InstitutionsApi* | [**private_institution_articles**](docs/InstitutionsApi.md#private_institution_articles) | **GET** /account/institution/articles | Private Institution Articles
*SwaggerClient::InstitutionsApi* | [**private_institution_details**](docs/InstitutionsApi.md#private_institution_details) | **GET** /account/institution | Private Account Institutions
*SwaggerClient::InstitutionsApi* | [**private_institution_embargo_options_details**](docs/InstitutionsApi.md#private_institution_embargo_options_details) | **GET** /account/institution/embargo_options | Private Account Institution embargo options
*SwaggerClient::InstitutionsApi* | [**private_institution_groups_list**](docs/InstitutionsApi.md#private_institution_groups_list) | **GET** /account/institution/groups | Private Account Institution Groups
*SwaggerClient::InstitutionsApi* | [**private_institution_roles_list**](docs/InstitutionsApi.md#private_institution_roles_list) | **GET** /account/institution/roles | Private Account Institution Roles
*SwaggerClient::OtherApi* | [**categories_list**](docs/OtherApi.md#categories_list) | **GET** /categories | Public Categories
*SwaggerClient::OtherApi* | [**file_download**](docs/OtherApi.md#file_download) | **GET** /file/download/{file_id} | Public File Download
*SwaggerClient::OtherApi* | [**item_types_list**](docs/OtherApi.md#item_types_list) | **GET** /item_types | Item Types
*SwaggerClient::OtherApi* | [**licenses_list**](docs/OtherApi.md#licenses_list) | **GET** /licenses | Public Licenses
*SwaggerClient::OtherApi* | [**private_account**](docs/OtherApi.md#private_account) | **GET** /account | Private Account information
*SwaggerClient::OtherApi* | [**private_funding_search**](docs/OtherApi.md#private_funding_search) | **POST** /account/funding/search | Search Funding
*SwaggerClient::OtherApi* | [**private_licenses_list**](docs/OtherApi.md#private_licenses_list) | **GET** /account/licenses | Private Account Licenses
*SwaggerClient::ProjectsApi* | [**private_project_article_delete**](docs/ProjectsApi.md#private_project_article_delete) | **DELETE** /account/projects/{project_id}/articles/{article_id} | Delete project article
*SwaggerClient::ProjectsApi* | [**private_project_article_details**](docs/ProjectsApi.md#private_project_article_details) | **GET** /account/projects/{project_id}/articles/{article_id} | Project article details
*SwaggerClient::ProjectsApi* | [**private_project_article_file**](docs/ProjectsApi.md#private_project_article_file) | **GET** /account/projects/{project_id}/articles/{article_id}/files/{file_id} | Project article file details
*SwaggerClient::ProjectsApi* | [**private_project_article_files**](docs/ProjectsApi.md#private_project_article_files) | **GET** /account/projects/{project_id}/articles/{article_id}/files | Project article list files
*SwaggerClient::ProjectsApi* | [**private_project_articles_create**](docs/ProjectsApi.md#private_project_articles_create) | **POST** /account/projects/{project_id}/articles | Create project article
*SwaggerClient::ProjectsApi* | [**private_project_articles_list**](docs/ProjectsApi.md#private_project_articles_list) | **GET** /account/projects/{project_id}/articles | List project articles
*SwaggerClient::ProjectsApi* | [**private_project_collaborator_delete**](docs/ProjectsApi.md#private_project_collaborator_delete) | **DELETE** /account/projects/{project_id}/collaborators/{user_id} | Remove project collaborator
*SwaggerClient::ProjectsApi* | [**private_project_collaborators_invite**](docs/ProjectsApi.md#private_project_collaborators_invite) | **POST** /account/projects/{project_id}/collaborators | Invite project collaborators
*SwaggerClient::ProjectsApi* | [**private_project_collaborators_list**](docs/ProjectsApi.md#private_project_collaborators_list) | **GET** /account/projects/{project_id}/collaborators | List project collaborators
*SwaggerClient::ProjectsApi* | [**private_project_create**](docs/ProjectsApi.md#private_project_create) | **POST** /account/projects | Create project
*SwaggerClient::ProjectsApi* | [**private_project_delete**](docs/ProjectsApi.md#private_project_delete) | **DELETE** /account/projects/{project_id} | Delete project
*SwaggerClient::ProjectsApi* | [**private_project_details**](docs/ProjectsApi.md#private_project_details) | **GET** /account/projects/{project_id} | View project details
*SwaggerClient::ProjectsApi* | [**private_project_leave**](docs/ProjectsApi.md#private_project_leave) | **POST** /account/projects/{project_id}/leave | Private Project Leave
*SwaggerClient::ProjectsApi* | [**private_project_note**](docs/ProjectsApi.md#private_project_note) | **GET** /account/projects/{project_id}/notes/{note_id} | Project note details
*SwaggerClient::ProjectsApi* | [**private_project_note_delete**](docs/ProjectsApi.md#private_project_note_delete) | **DELETE** /account/projects/{project_id}/notes/{note_id} | Delete project note
*SwaggerClient::ProjectsApi* | [**private_project_note_update**](docs/ProjectsApi.md#private_project_note_update) | **PUT** /account/projects/{project_id}/notes/{note_id} | Update project note
*SwaggerClient::ProjectsApi* | [**private_project_notes_create**](docs/ProjectsApi.md#private_project_notes_create) | **POST** /account/projects/{project_id}/notes | Create project note
*SwaggerClient::ProjectsApi* | [**private_project_notes_list**](docs/ProjectsApi.md#private_project_notes_list) | **GET** /account/projects/{project_id}/notes | List project notes
*SwaggerClient::ProjectsApi* | [**private_project_publish**](docs/ProjectsApi.md#private_project_publish) | **POST** /account/projects/{project_id}/publish | Private Project Publish
*SwaggerClient::ProjectsApi* | [**private_project_update**](docs/ProjectsApi.md#private_project_update) | **PUT** /account/projects/{project_id} | Update project
*SwaggerClient::ProjectsApi* | [**private_projects_list**](docs/ProjectsApi.md#private_projects_list) | **GET** /account/projects | Private Projects
*SwaggerClient::ProjectsApi* | [**private_projects_search**](docs/ProjectsApi.md#private_projects_search) | **POST** /account/projects/search | Private Projects search
*SwaggerClient::ProjectsApi* | [**project_articles**](docs/ProjectsApi.md#project_articles) | **GET** /projects/{project_id}/articles | Public Project Articles
*SwaggerClient::ProjectsApi* | [**project_details**](docs/ProjectsApi.md#project_details) | **GET** /projects/{project_id} | Public Project
*SwaggerClient::ProjectsApi* | [**projects_list**](docs/ProjectsApi.md#projects_list) | **GET** /projects | Public Projects
*SwaggerClient::ProjectsApi* | [**projects_search**](docs/ProjectsApi.md#projects_search) | **POST** /projects/search | Public Projects Search


## Documentation for Models

 - [SwaggerClient::Account](docs/Account.md)
 - [SwaggerClient::AccountCreate](docs/AccountCreate.md)
 - [SwaggerClient::AccountGroupRoles](docs/AccountGroupRoles.md)
 - [SwaggerClient::AccountGroupRolesCreate](docs/AccountGroupRolesCreate.md)
 - [SwaggerClient::AccountReport](docs/AccountReport.md)
 - [SwaggerClient::AccountUpdate](docs/AccountUpdate.md)
 - [SwaggerClient::Article](docs/Article.md)
 - [SwaggerClient::ArticleComplete](docs/ArticleComplete.md)
 - [SwaggerClient::ArticleCompletePrivate](docs/ArticleCompletePrivate.md)
 - [SwaggerClient::ArticleConfidentiality](docs/ArticleConfidentiality.md)
 - [SwaggerClient::ArticleCreate](docs/ArticleCreate.md)
 - [SwaggerClient::ArticleDOI](docs/ArticleDOI.md)
 - [SwaggerClient::ArticleEmbargo](docs/ArticleEmbargo.md)
 - [SwaggerClient::ArticleEmbargoUpdater](docs/ArticleEmbargoUpdater.md)
 - [SwaggerClient::ArticleHandle](docs/ArticleHandle.md)
 - [SwaggerClient::ArticleProjectCreate](docs/ArticleProjectCreate.md)
 - [SwaggerClient::ArticleSearch](docs/ArticleSearch.md)
 - [SwaggerClient::ArticleUpdate](docs/ArticleUpdate.md)
 - [SwaggerClient::ArticleVersions](docs/ArticleVersions.md)
 - [SwaggerClient::ArticleWithProject](docs/ArticleWithProject.md)
 - [SwaggerClient::ArticlesCreator](docs/ArticlesCreator.md)
 - [SwaggerClient::Author](docs/Author.md)
 - [SwaggerClient::AuthorComplete](docs/AuthorComplete.md)
 - [SwaggerClient::AuthorsCreator](docs/AuthorsCreator.md)
 - [SwaggerClient::CategoriesCreator](docs/CategoriesCreator.md)
 - [SwaggerClient::Category](docs/Category.md)
 - [SwaggerClient::Collaborator](docs/Collaborator.md)
 - [SwaggerClient::Collection](docs/Collection.md)
 - [SwaggerClient::CollectionComplete](docs/CollectionComplete.md)
 - [SwaggerClient::CollectionCompletePrivate](docs/CollectionCompletePrivate.md)
 - [SwaggerClient::CollectionCreate](docs/CollectionCreate.md)
 - [SwaggerClient::CollectionDOI](docs/CollectionDOI.md)
 - [SwaggerClient::CollectionHandle](docs/CollectionHandle.md)
 - [SwaggerClient::CollectionPrivateLinkCreator](docs/CollectionPrivateLinkCreator.md)
 - [SwaggerClient::CollectionSearch](docs/CollectionSearch.md)
 - [SwaggerClient::CollectionUpdate](docs/CollectionUpdate.md)
 - [SwaggerClient::CollectionVersions](docs/CollectionVersions.md)
 - [SwaggerClient::CommonSearch](docs/CommonSearch.md)
 - [SwaggerClient::ConfidentialityCreator](docs/ConfidentialityCreator.md)
 - [SwaggerClient::CreateProjectResponse](docs/CreateProjectResponse.md)
 - [SwaggerClient::Curation](docs/Curation.md)
 - [SwaggerClient::CurationComment](docs/CurationComment.md)
 - [SwaggerClient::CurationCommentCreate](docs/CurationCommentCreate.md)
 - [SwaggerClient::CurationDetail](docs/CurationDetail.md)
 - [SwaggerClient::CustomArticleField](docs/CustomArticleField.md)
 - [SwaggerClient::CustomArticleFieldAdd](docs/CustomArticleFieldAdd.md)
 - [SwaggerClient::ErrorMessage](docs/ErrorMessage.md)
 - [SwaggerClient::FileCreator](docs/FileCreator.md)
 - [SwaggerClient::FileId](docs/FileId.md)
 - [SwaggerClient::FundingCreate](docs/FundingCreate.md)
 - [SwaggerClient::FundingInformation](docs/FundingInformation.md)
 - [SwaggerClient::FundingSearch](docs/FundingSearch.md)
 - [SwaggerClient::Group](docs/Group.md)
 - [SwaggerClient::GroupEmbargoOptions](docs/GroupEmbargoOptions.md)
 - [SwaggerClient::Institution](docs/Institution.md)
 - [SwaggerClient::InstitutionAccountsSearch](docs/InstitutionAccountsSearch.md)
 - [SwaggerClient::ItemType](docs/ItemType.md)
 - [SwaggerClient::License](docs/License.md)
 - [SwaggerClient::Location](docs/Location.md)
 - [SwaggerClient::LocationWarnings](docs/LocationWarnings.md)
 - [SwaggerClient::LocationWarningsUpdate](docs/LocationWarningsUpdate.md)
 - [SwaggerClient::PrivateArticleSearch](docs/PrivateArticleSearch.md)
 - [SwaggerClient::PrivateAuthorsSearch](docs/PrivateAuthorsSearch.md)
 - [SwaggerClient::PrivateCollectionSearch](docs/PrivateCollectionSearch.md)
 - [SwaggerClient::PrivateFile](docs/PrivateFile.md)
 - [SwaggerClient::PrivateLink](docs/PrivateLink.md)
 - [SwaggerClient::PrivateLinkCreator](docs/PrivateLinkCreator.md)
 - [SwaggerClient::PrivateLinkResponse](docs/PrivateLinkResponse.md)
 - [SwaggerClient::Project](docs/Project.md)
 - [SwaggerClient::ProjectArticle](docs/ProjectArticle.md)
 - [SwaggerClient::ProjectCollaborator](docs/ProjectCollaborator.md)
 - [SwaggerClient::ProjectCollaboratorInvite](docs/ProjectCollaboratorInvite.md)
 - [SwaggerClient::ProjectComplete](docs/ProjectComplete.md)
 - [SwaggerClient::ProjectCompletePrivate](docs/ProjectCompletePrivate.md)
 - [SwaggerClient::ProjectCreate](docs/ProjectCreate.md)
 - [SwaggerClient::ProjectNote](docs/ProjectNote.md)
 - [SwaggerClient::ProjectNoteCreate](docs/ProjectNoteCreate.md)
 - [SwaggerClient::ProjectNotePrivate](docs/ProjectNotePrivate.md)
 - [SwaggerClient::ProjectPrivate](docs/ProjectPrivate.md)
 - [SwaggerClient::ProjectUpdate](docs/ProjectUpdate.md)
 - [SwaggerClient::ProjectsSearch](docs/ProjectsSearch.md)
 - [SwaggerClient::PublicFile](docs/PublicFile.md)
 - [SwaggerClient::RelatedMaterial](docs/RelatedMaterial.md)
 - [SwaggerClient::Resource](docs/Resource.md)
 - [SwaggerClient::ResponseMessage](docs/ResponseMessage.md)
 - [SwaggerClient::Role](docs/Role.md)
 - [SwaggerClient::ShortAccount](docs/ShortAccount.md)
 - [SwaggerClient::ShortCustomField](docs/ShortCustomField.md)
 - [SwaggerClient::Timeline](docs/Timeline.md)
 - [SwaggerClient::TimelineUpdate](docs/TimelineUpdate.md)
 - [SwaggerClient::UploadFilePart](docs/UploadFilePart.md)
 - [SwaggerClient::UploadInfo](docs/UploadInfo.md)
 - [SwaggerClient::User](docs/User.md)


## Documentation for Authorization


### OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://figshare.com/account/applications/authorize
- **Scopes**: 
  - all: Grants all access

